pilot.api.data.api.PilotDataService

Package pilot :: Package api :: Package data :: Module api :: Class PilotDataService |

# Class PilotDataService

source code

PilotDataService (PDS).

Instance Methods
__init__(self, pss_id=None) Create a PilotDataService | source code
cancel(self) Cancel the PilotDataService. | source code
create_pilot(self, pilot_data_description) Create a PilotData | source code
list_pilots(self) List all PDs of PDS | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
| id
| pilot_data
| state
Inherited from `object`: `__class__`

Method Details

### __init__(self, pss_id=None) (Constructor) | source code
Create a PilotDataService Keyword arguments: pss_id -- restore from pss_id Overrides: object.__init__

### cancel(self) | source code
Cancel the PilotDataService. Keyword arguments: None Return value: Result of operation

### create_pilot(self, pilot_data_description) | source code
Create a PilotData Keyword arguments: pilot_data_description -- PilotData Description Return value: A PilotData handle